@@ -3,7 +3,7 @@
 *                              D e b u g   T a r g e t                          *
 *                                                                               *
 *********************************************************************************
-* Copyright (C) 1998,2002 by Jeroen van der Zijp.   All Rights Reserved.        *
+* Copyright (C) 1998,2006 by Jeroen van der Zijp.   All Rights Reserved.        *
 *********************************************************************************
 * This library is free software; you can redistribute it and/or                 *
 * modify it under the terms of the GNU Lesser General Public                    *
@@ -19,7 +19,7 @@
 * License along with this library; if not, write to the Free Software           *
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA.    *
 *********************************************************************************
-* $Id: FXDebugTarget.h,v 1.9 2002/01/18 22:42:52 jeroen Exp $                   *
+* $Id: FXDebugTarget.h,v 1.15 2006/01/22 17:58:00 fox Exp $                     *
 ********************************************************************************/
 #ifndef FXDEBUGTARGET_H
 #define FXDEBUGTARGET_H
@@ -28,6 +28,7 @@
 #include "FXObject.h"
 #endif
 
+namespace FX {
 
 
 /**
@@ -55,7 +56,6 @@ public:
 
   };
 
-
-
+}
 
 #endif
