@@ -3,7 +3,7 @@
 *                    B i t m a p   V i e w   W i d g e t                        *
 *                                                                               *
 *********************************************************************************
-* Copyright (C) 2000,2005 by Jeroen van der Zijp.   All Rights Reserved.        *
+* Copyright (C) 2000,2006 by Jeroen van der Zijp.   All Rights Reserved.        *
 *********************************************************************************
 * This library is free software; you can redistribute it and/or                 *
 * modify it under the terms of the GNU Lesser General Public                    *
@@ -19,7 +19,7 @@
 * License along with this library; if not, write to the Free Software           *
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA.    *
 *********************************************************************************
-* $Id: FXBitmapView.cpp,v 1.12 2005/01/16 16:06:06 fox Exp $                    *
+* $Id: FXBitmapView.cpp,v 1.16 2006/01/22 17:58:18 fox Exp $                    *
 ********************************************************************************/
 #include "xincs.h"
 #include "fxver.h"
@@ -113,7 +113,7 @@ void FXBitmapView::detach(){
 
 
 // Can have focus
-FXbool FXBitmapView::canFocus() const { return TRUE; }
+bool FXBitmapView::canFocus() const { return true; }
 
 
 // Determine content width of scroll area
