@@ -3,7 +3,7 @@
 *                        C U R   C u r s o r    O b j e c t                     *
 *                                                                               *
 *********************************************************************************
-* Copyright (C) 2001,2005 by Sander Jansen.   All Rights Reserved.              *
+* Copyright (C) 2001,2006 by Sander Jansen.   All Rights Reserved.              *
 *********************************************************************************
 * This library is free software; you can redistribute it and/or                 *
 * modify it under the terms of the GNU Lesser General Public                    *
@@ -19,7 +19,7 @@
 * License along with this library; if not, write to the Free Software           *
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA.    *
 *********************************************************************************
-* $Id: FXCURCursor.cpp,v 1.21 2005/01/16 16:06:06 fox Exp $                     *
+* $Id: FXCURCursor.cpp,v 1.25 2006/01/22 17:58:18 fox Exp $                     *
 ********************************************************************************/
 #include "xincs.h"
 #include "fxver.h"
@@ -74,22 +74,22 @@ FXCURCursor::FXCURCursor(FXApp* a,const void *pix):FXCursor(a,NULL,0,0,0,0){
 
 
 // Save pixel data only, in CUR format
-FXbool FXCURCursor::savePixels(FXStream& store) const {
+bool FXCURCursor::savePixels(FXStream& store) const {
   if(fxsaveICO(store,data,width,height,hotx,hoty)){
-    return TRUE;
+    return true;
     }
-  return FALSE;
+  return false;
   }
 
 
 // Load cursor mask and image
-FXbool FXCURCursor::loadPixels(FXStream & store){
+bool FXCURCursor::loadPixels(FXStream & store){
   if(options&CURSOR_OWNED){FXFREE(&data);}
   if(fxloadICO(store,data,width,height,hotx,hoty)){
     options|=CURSOR_OWNED;
-    return TRUE;
+    return true;
     }
-  return FALSE;
+  return false;
   }
 
 
