@@ -3,7 +3,7 @@
 *                    C h e c k   B u t t o n    O b j e c t                     *
 *                                                                               *
 *********************************************************************************
-* Copyright (C) 1998,2005 by Jeroen van der Zijp.   All Rights Reserved.        *
+* Copyright (C) 1998,2006 by Jeroen van der Zijp.   All Rights Reserved.        *
 *********************************************************************************
 * This library is free software; you can redistribute it and/or                 *
 * modify it under the terms of the GNU Lesser General Public                    *
@@ -19,7 +19,7 @@
 * License along with this library; if not, write to the Free Software           *
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA.    *
 *********************************************************************************
-* $Id: FXCheckButton.cpp,v 1.52 2005/01/16 16:06:06 fox Exp $                   *
+* $Id: FXCheckButton.cpp,v 1.58 2006/01/22 17:58:20 fox Exp $                   *
 ********************************************************************************/
 #include "xincs.h"
 #include "fxver.h"
@@ -103,7 +103,7 @@ FXCheckButton::FXCheckButton(FXComposite* p,const FXString& text,FXObject* tgt,F
 
 
 // If window can have focus
-FXbool FXCheckButton::canFocus() const { return 1; }
+bool FXCheckButton::canFocus() const { return true; }
 
 
 // Get default width
@@ -130,10 +130,11 @@ FXint FXCheckButton::getDefaultHeight(){
 
 
 // Check button
-void FXCheckButton::setCheck(FXbool state){
+void FXCheckButton::setCheck(FXbool state,FXbool notify){
   if(check!=state){
     check=state;
     update();
+    if(notify && target){target->tryHandle(this,FXSEL(SEL_COMMAND,message),(void*)(FXuval)check);}
     }
   }
 
