@@ -19,7 +19,7 @@
 * License along with this library; if not, write to the Free Software           *
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA.    *
 *********************************************************************************
-* $Id: FXDial.cpp,v 1.50 2006/01/22 17:58:22 fox Exp $                          *
+* $Id: FXDial.cpp,v 1.50.2.1 2007/09/22 04:28:37 fox Exp $                          *
 ********************************************************************************/
 #include "xincs.h"
 #include "fxver.h"
@@ -404,13 +404,11 @@ long FXDial::onKeyPress(FXObject*,FXSelector,void* ptr){
         break;
       case KEY_plus:
       case KEY_KP_Add:
-inc:    //setValue(pos+((incr+359)/360),TRUE);
-        setValue(pos+1);
+inc:    setValue(pos+1,TRUE);
         return 1;
       case KEY_minus:
       case KEY_KP_Subtract:
-dec:    //setValue(pos-((incr+359)/360),TRUE);
-        setValue(pos-1);
+dec:    setValue(pos-1,TRUE);
         return 1;
       }
     }
