@@ -3,7 +3,7 @@
 *                            G I F   I m a g e   O b j e c t                    *
 *                                                                               *
 *********************************************************************************
-* Copyright (C) 1998,2005 by Jeroen van der Zijp.   All Rights Reserved.        *
+* Copyright (C) 1998,2006 by Jeroen van der Zijp.   All Rights Reserved.        *
 *********************************************************************************
 * This library is free software; you can redistribute it and/or                 *
 * modify it under the terms of the GNU Lesser General Public                    *
@@ -19,7 +19,7 @@
 * License along with this library; if not, write to the Free Software           *
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA.    *
 *********************************************************************************
-* $Id: FXGIFImage.cpp,v 1.30 2005/01/16 16:06:07 fox Exp $                      *
+* $Id: FXGIFImage.cpp,v 1.35 2006/01/22 17:58:27 fox Exp $                      *
 ********************************************************************************/
 #include "xincs.h"
 #include "fxver.h"
@@ -56,6 +56,10 @@ namespace FX {
 const FXchar FXGIFImage::fileExt[]="gif";
 
 
+// Suggested mime type
+const FXchar FXGIFImage::mimeType[]="image/gif";
+
+
 // Object implementation
 FXIMPLEMENT(FXGIFImage,FXImage,NULL,0)
 
@@ -72,22 +76,22 @@ FXGIFImage::FXGIFImage(FXApp* a,const void *pix,FXuint opts,FXint w,FXint h):FXI
 
 
 // Save object to stream
-FXbool FXGIFImage::savePixels(FXStream& store) const {
+bool FXGIFImage::savePixels(FXStream& store) const {
   if(fxsaveGIF(store,data,width,height)){
-    return TRUE;
+    return true;
     }
-  return FALSE;
+  return false;
   }
 
 
 // Load object from stream
-FXbool FXGIFImage::loadPixels(FXStream& store){
+bool FXGIFImage::loadPixels(FXStream& store){
   FXColor *pixels; FXint w,h;
   if(fxloadGIF(store,pixels,w,h)){
     setData(pixels,IMAGE_OWNED,w,h);
-    return TRUE;
+    return true;
     }
-  return FALSE;
+  return false;
   }
 
 
