@@ -3,7 +3,7 @@
 *                        I C O   I c o n   O b j e c t                          *
 *                                                                               *
 *********************************************************************************
-* Copyright (C) 2001,2005 by Janusz Ganczarski.   All Rights Reserved.          *
+* Copyright (C) 2001,2006 by Janusz Ganczarski.   All Rights Reserved.          *
 *********************************************************************************
 * This library is free software; you can redistribute it and/or                 *
 * modify it under the terms of the GNU Lesser General Public                    *
@@ -19,7 +19,7 @@
 * License along with this library; if not, write to the Free Software           *
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA.    *
 *********************************************************************************
-* $Id: FXICOIcon.cpp,v 1.22 2005/01/16 16:06:07 fox Exp $                       *
+* $Id: FXICOIcon.cpp,v 1.27 2006/01/22 17:58:31 fox Exp $                       *
 ********************************************************************************/
 #include "xincs.h"
 #include "fxver.h"
@@ -52,6 +52,10 @@ namespace FX {
 const FXchar FXICOIcon::fileExt[]="ico";
 
 
+// Suggested mime type
+const FXchar FXICOIcon::mimeType[]="image/ico";
+
+
 // Object implementation
 FXIMPLEMENT(FXICOIcon,FXIcon,NULL,0)
 
@@ -68,23 +72,23 @@ FXICOIcon::FXICOIcon(FXApp* a,const void *pix,FXColor clr,FXuint opts,FXint w,FX
 
 
 // Save object to stream
-FXbool FXICOIcon::savePixels(FXStream& store) const {
+bool FXICOIcon::savePixels(FXStream& store) const {
   if(fxsaveICO(store,data,width,height,0,0)){
-    return TRUE;
+    return true;
     }
-  return FALSE;
+  return false;
   }
 
 
 // Load object from stream
-FXbool FXICOIcon::loadPixels(FXStream& store){
+bool FXICOIcon::loadPixels(FXStream& store){
   FXColor *pixels; FXint w,h,hotx,hoty;
   if(fxloadICO(store,pixels,w,h,hotx,hoty)){
     setData(pixels,IMAGE_OWNED,w,h);
     if(options&IMAGE_ALPHAGUESS) transp=guesstransp();
-    return TRUE;
+    return true;
     }
-  return FALSE;
+  return false;
   }
 
 
