@@ -3,7 +3,7 @@
 *                          I C O   I m a g e   O b j e c t                      *
 *                                                                               *
 *********************************************************************************
-* Copyright (C) 2001,2005 by Janusz Ganczarski.   All Rights Reserved.          *
+* Copyright (C) 2001,2006 by Janusz Ganczarski.   All Rights Reserved.          *
 *********************************************************************************
 * This library is free software; you can redistribute it and/or                 *
 * modify it under the terms of the GNU Lesser General Public                    *
@@ -19,7 +19,7 @@
 * License along with this library; if not, write to the Free Software           *
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA.    *
 *********************************************************************************
-* $Id: FXICOImage.cpp,v 1.23 2005/01/16 16:06:07 fox Exp $                      *
+* $Id: FXICOImage.cpp,v 1.28 2006/01/22 17:58:31 fox Exp $                      *
 ********************************************************************************/
 #include "xincs.h"
 #include "fxver.h"
@@ -53,6 +53,10 @@ namespace FX {
 const FXchar FXICOImage::fileExt[]="ico";
 
 
+// Suggested mime type
+const FXchar FXICOImage::mimeType[]="image/ico";
+
+
 // Object implementation
 FXIMPLEMENT(FXICOImage,FXImage,NULL,0)
 
@@ -69,22 +73,22 @@ FXICOImage::FXICOImage(FXApp* a,const void *pix,FXuint opts,FXint w,FXint h):FXI
 
 
 // Save pixel data only
-FXbool FXICOImage::savePixels(FXStream& store) const {
+bool FXICOImage::savePixels(FXStream& store) const {
   if(fxsaveICO(store,data,width,height,0,0)){
-    return TRUE;
+    return true;
     }
-  return FALSE;
+  return false;
   }
 
 
 // Load pixel data only
-FXbool FXICOImage::loadPixels(FXStream& store){
+bool FXICOImage::loadPixels(FXStream& store){
   FXColor *pixels; FXint w,h,hotx,hoty;
   if(fxloadICO(store,pixels,w,h,hotx,hoty)){
     setData(pixels,IMAGE_OWNED,w,h);
-    return TRUE;
+    return true;
     }
-  return FALSE;
+  return false;
   }
 
 
