@@ -3,7 +3,7 @@
 *                         J P E G   I c o n   O b j e c t                       *
 *                                                                               *
 *********************************************************************************
-* Copyright (C) 2000,2005 by David Tyree.   All Rights Reserved.                *
+* Copyright (C) 2000,2006 by David Tyree.   All Rights Reserved.                *
 *********************************************************************************
 * This library is free software; you can redistribute it and/or                 *
 * modify it under the terms of the GNU Lesser General Public                    *
@@ -19,7 +19,7 @@
 * License along with this library; if not, write to the Free Software           *
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA.    *
 *********************************************************************************
-* $Id: FXJPGIcon.cpp,v 1.22 2005/01/16 16:06:07 fox Exp $                       *
+* $Id: FXJPGIcon.cpp,v 1.28 2006/01/24 13:53:11 fox Exp $                       *
 ********************************************************************************/
 #include "xincs.h"
 #include "fxver.h"
@@ -53,19 +53,23 @@ namespace FX {
 const FXchar FXJPGIcon::fileExt[]="jpg";
 
 
+// Suggested mime type
+const FXchar FXJPGIcon::mimeType[]="image/jpeg";
+
+
 // Object implementation
 FXIMPLEMENT(FXJPGIcon,FXIcon,NULL,0)
 
 
 #ifdef HAVE_JPEG_H
-const FXbool FXJPGIcon::supported=TRUE;
+const bool FXJPGIcon::supported=true;
 #else
-const FXbool FXJPGIcon::supported=FALSE;
+const bool FXJPGIcon::supported=false;
 #endif
 
 
 // Initialize
-FXJPGIcon::FXJPGIcon(FXApp* a,const void *pix,FXColor clr,FXuint opts,FXint w,FXint h):FXIcon(a,NULL,clr,opts,w,h),quality(75){
+FXJPGIcon::FXJPGIcon(FXApp* a,const void *pix,FXColor clr,FXuint opts,FXint w,FXint h,FXint q):FXIcon(a,NULL,clr,opts,w,h),quality(q){
   if(pix){
     FXMemoryStream ms;
     ms.open(FXStreamLoad,(FXuchar*)pix);
@@ -76,23 +80,23 @@ FXJPGIcon::FXJPGIcon(FXApp* a,const void *pix,FXColor clr,FXuint opts,FXint w,FX
 
 
 // Save pixels only
-FXbool FXJPGIcon::savePixels(FXStream& store) const {
+bool FXJPGIcon::savePixels(FXStream& store) const {
   if(fxsaveJPG(store,data,width,height,quality)){
-    return TRUE;
+    return true;
     }
-  return FALSE;
+  return false;
   }
 
 
 // Load pixels only
-FXbool FXJPGIcon::loadPixels(FXStream& store){
+bool FXJPGIcon::loadPixels(FXStream& store){
   FXColor *pixels; FXint w,h;
   if(fxloadJPG(store,pixels,w,h,quality)){
     setData(pixels,IMAGE_OWNED,w,h);
     if(options&IMAGE_ALPHAGUESS) transp=guesstransp();
-    return TRUE;
+    return true;
     }
-  return FALSE;
+  return false;
   }
 
 
