@@ -3,7 +3,7 @@
 *             M u l t i p l e   D o c u m e n t   B u t t o n                   *
 *                                                                               *
 *********************************************************************************
-* Copyright (C) 1998,2005 by Jeroen van der Zijp.   All Rights Reserved.        *
+* Copyright (C) 1998,2006 by Jeroen van der Zijp.   All Rights Reserved.        *
 *********************************************************************************
 * This library is free software; you can redistribute it and/or                 *
 * modify it under the terms of the GNU Lesser General Public                    *
@@ -19,7 +19,7 @@
 * License along with this library; if not, write to the Free Software           *
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA.    *
 *********************************************************************************
-* $Id: FXMDIButton.cpp,v 1.24 2005/01/16 16:06:07 fox Exp $                     *
+* $Id: FXMDIButton.cpp,v 1.28 2006/01/22 17:58:33 fox Exp $                     *
 ********************************************************************************/
 #include "xincs.h"
 #include "fxver.h"
@@ -94,11 +94,10 @@ FXint FXMDIDeleteButton::getDefaultHeight(){
 
 // Handle repaint
 long FXMDIDeleteButton::onPaint(FXObject*,FXSelector,void* ptr){
-  FXEvent *ev=(FXEvent*)ptr;
-  FXDCWindow dc(this,ev);
+  FXDCWindow dc(this,(FXEvent*)ptr);
   FXint xx,yy;
   dc.setForeground(backColor);
-  dc.fillRectangle(ev->rect.x,ev->rect.y,ev->rect.w,ev->rect.h);
+  dc.fillRectangle(0,0,width,height);
   if(options&(FRAME_RAISED|FRAME_SUNKEN)){
     if(state==STATE_UP){
       if(options&FRAME_THICK) drawDoubleRaisedRectangle(dc,0,0,width,height);
@@ -166,11 +165,10 @@ FXint FXMDIRestoreButton::getDefaultHeight(){
 
 // Handle repaint
 long FXMDIRestoreButton::onPaint(FXObject*,FXSelector,void* ptr){
-  FXEvent *ev=(FXEvent*)ptr;
-  FXDCWindow dc(this,ev);
+  FXDCWindow dc(this,(FXEvent*)ptr);
   FXint xx,yy;
   dc.setForeground(backColor);
-  dc.fillRectangle(ev->rect.x,ev->rect.y,ev->rect.w,ev->rect.h);
+  dc.fillRectangle(0,0,width,height);
   if(options&(FRAME_RAISED|FRAME_SUNKEN)){
     if(state==STATE_UP){
       if(options&FRAME_THICK) drawDoubleRaisedRectangle(dc,0,0,width,height);
@@ -232,11 +230,10 @@ FXint FXMDIMaximizeButton::getDefaultHeight(){
 
 // Handle repaint
 long FXMDIMaximizeButton::onPaint(FXObject*,FXSelector,void* ptr){
-  FXEvent *ev=(FXEvent*)ptr;
-  FXDCWindow dc(this,ev);
+  FXDCWindow dc(this,(FXEvent*)ptr);
   FXint xx,yy;
   dc.setForeground(backColor);
-  dc.fillRectangle(ev->rect.x,ev->rect.y,ev->rect.w,ev->rect.h);
+  dc.fillRectangle(0,0,width,height);
   if(options&(FRAME_RAISED|FRAME_SUNKEN)){
     if(state==STATE_UP){
       if(options&FRAME_THICK) drawDoubleRaisedRectangle(dc,0,0,width,height);
@@ -291,11 +288,10 @@ FXint FXMDIMinimizeButton::getDefaultHeight(){
 
 // Handle repaint
 long FXMDIMinimizeButton::onPaint(FXObject*,FXSelector,void* ptr){
-  FXEvent *ev=(FXEvent*)ptr;
-  FXDCWindow dc(this,ev);
+  FXDCWindow dc(this,(FXEvent*)ptr);
   FXint xx,yy;
   dc.setForeground(backColor);
-  dc.fillRectangle(ev->rect.x,ev->rect.y,ev->rect.w,ev->rect.h);
+  dc.fillRectangle(0,0,width,height);
   if(options&(FRAME_RAISED|FRAME_SUNKEN)){
     if(state==STATE_UP){
       if(options&FRAME_THICK) drawDoubleRaisedRectangle(dc,0,0,width,height);
@@ -334,7 +330,7 @@ FXIMPLEMENT(FXMDIWindowButton,FXMenuButton,FXMDIWindowButtonMap,ARRAYNUMBER(FXMD
 
 // Make window button
 FXMDIWindowButton::FXMDIWindowButton(FXComposite* p,FXPopup* pup,FXObject* tgt,FXSelector sel,FXuint opts,FXint x,FXint y,FXint w,FXint h):
-  FXMenuButton(p,NULL,NULL,pup,opts,x,y,w,h,0,0,0,0){
+  FXMenuButton(p,FXString::null,NULL,pup,opts,x,y,w,h,0,0,0,0){
   tip="Menu";
   target=tgt;
   message=sel;
@@ -355,11 +351,10 @@ FXint FXMDIWindowButton::getDefaultHeight(){
 
 // Handle repaint
 long FXMDIWindowButton::onPaint(FXObject*,FXSelector,void* ptr){
-  FXEvent *ev=(FXEvent*)ptr;
-  FXDCWindow dc(this,ev);
+  FXDCWindow dc(this,(FXEvent*)ptr);
   FXint ix,iy,iw,ih;
   dc.setForeground(backColor);
-  dc.fillRectangle(ev->rect.x,ev->rect.y,ev->rect.w,ev->rect.h);
+  dc.fillRectangle(0,0,width,height);
   drawFrame(dc,0,0,width,height);
   if(icon){
     iw=icon->getWidth();
