@@ -3,7 +3,7 @@
 *            S i n g l e - P r e c i s i o n   4 x 4   M a t r i x              *
 *                                                                               *
 *********************************************************************************
-* Copyright (C) 1994,2005 by Jeroen van der Zijp.   All Rights Reserved.        *
+* Copyright (C) 1994,2006 by Jeroen van der Zijp.   All Rights Reserved.        *
 *********************************************************************************
 * This library is free software; you can redistribute it and/or                 *
 * modify it under the terms of the GNU Lesser General Public                    *
@@ -19,7 +19,7 @@
 * License along with this library; if not, write to the Free Software           *
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA.    *
 *********************************************************************************
-* $Id: FXMat4f.cpp,v 1.11 2005/01/16 16:06:07 fox Exp $                         *
+* $Id: FXMat4f.cpp,v 1.16 2006/01/22 17:58:35 fox Exp $                         *
 ********************************************************************************/
 #include "xincs.h"
 #include "fxver.h"
@@ -124,6 +124,49 @@ FXMat4f& FXMat4f::operator=(FXfloat w){
   }
 
 
+// Set value from another matrix
+FXMat4f& FXMat4f::set(const FXMat4f& other){
+  m[0]=other[0];
+  m[1]=other[1];
+  m[2]=other[2];
+  m[3]=other[3];
+  return *this;
+  }
+
+
+// Construct from scalar number
+FXMat4f& FXMat4f::set(FXfloat w){
+  m[0][0]=w; m[0][1]=w; m[0][2]=w; m[0][3]=w;
+  m[1][0]=w; m[1][1]=w; m[1][2]=w; m[1][3]=w;
+  m[2][0]=w; m[2][1]=w; m[2][2]=w; m[2][3]=w;
+  m[3][0]=w; m[3][1]=w; m[3][2]=w; m[3][3]=w;
+  return *this;
+  }
+
+
+// Construct from components
+FXMat4f& FXMat4f::set(FXfloat a00,FXfloat a01,FXfloat a02,FXfloat a03,
+                      FXfloat a10,FXfloat a11,FXfloat a12,FXfloat a13,
+                      FXfloat a20,FXfloat a21,FXfloat a22,FXfloat a23,
+                      FXfloat a30,FXfloat a31,FXfloat a32,FXfloat a33){
+  m[0][0]=a00; m[0][1]=a01; m[0][2]=a02; m[0][3]=a03;
+  m[1][0]=a10; m[1][1]=a11; m[1][2]=a12; m[1][3]=a13;
+  m[2][0]=a20; m[2][1]=a21; m[2][2]=a22; m[2][3]=a23;
+  m[3][0]=a30; m[3][1]=a31; m[3][2]=a32; m[3][3]=a33;
+  return *this;
+  }
+
+
+// Construct matrix from three vectors
+FXMat4f& FXMat4f::set(const FXVec4f& a,const FXVec4f& b,const FXVec4f& c,const FXVec4f& d){
+  m[0][0]=a[0]; m[0][1]=a[1]; m[0][2]=a[2]; m[0][3]=a[3];
+  m[1][0]=b[0]; m[1][1]=b[1]; m[1][2]=b[2]; m[1][3]=b[3];
+  m[2][0]=c[0]; m[2][1]=c[1]; m[2][2]=c[2]; m[2][3]=c[3];
+  m[3][0]=d[0]; m[3][1]=d[1]; m[3][2]=d[2]; m[3][3]=d[3];
+  return *this;
+  }
+
+
 // Add matrices
 FXMat4f& FXMat4f::operator+=(const FXMat4f& w){
   m[0][0]+=w[0][0]; m[0][1]+=w[0][1]; m[0][2]+=w[0][2]; m[0][3]+=w[0][3];
@@ -191,58 +234,57 @@ FXMat4f& FXMat4f::operator/=(FXfloat w){
   }
 
 
+// Unary minus
+FXMat4f FXMat4f::operator-() const {
+  return FXMat4f(-m[0][0],-m[0][1],-m[0][2],-m[0][3],
+                 -m[1][0],-m[1][1],-m[1][2],-m[1][3],
+                 -m[2][0],-m[2][1],-m[2][2],-m[2][3],
+                 -m[3][0],-m[3][1],-m[3][2],-m[3][3]);
+  }
+
+
 // Add matrices
-FXMat4f operator+(const FXMat4f& a,const FXMat4f& b){
-  return FXMat4f(a[0][0]+b[0][0],a[0][1]+b[0][1],a[0][2]+b[0][2],a[0][3]+b[0][3],
-                 a[1][0]+b[1][0],a[1][1]+b[1][1],a[1][2]+b[1][2],a[1][3]+b[1][3],
-                 a[2][0]+b[2][0],a[2][1]+b[2][1],a[2][2]+b[2][2],a[2][3]+b[2][3],
-                 a[3][0]+b[3][0],a[3][1]+b[3][1],a[3][2]+b[3][2],a[3][3]+b[3][3]);
+FXMat4f FXMat4f::operator+(const FXMat4f& w) const {
+  return FXMat4f(m[0][0]+w[0][0],m[0][1]+w[0][1],m[0][2]+w[0][2],m[0][3]+w[0][3],
+                 m[1][0]+w[1][0],m[1][1]+w[1][1],m[1][2]+w[1][2],m[1][3]+w[1][3],
+                 m[2][0]+w[2][0],m[2][1]+w[2][1],m[2][2]+w[2][2],m[2][3]+w[2][3],
+                 m[3][0]+w[3][0],m[3][1]+w[3][1],m[3][2]+w[3][2],m[3][3]+w[3][3]);
   }
 
 
 // Substract matrices
-FXMat4f operator-(const FXMat4f& a,const FXMat4f& b){
-  return FXMat4f(a.m[0][0]-b.m[0][0],a.m[0][1]-b.m[0][1],a.m[0][2]-b.m[0][2],a.m[0][3]-b.m[0][3],
-                 a.m[1][0]-b.m[1][0],a.m[1][1]-b.m[1][1],a.m[1][2]-b.m[1][2],a.m[1][3]-b.m[1][3],
-                 a.m[2][0]-b.m[2][0],a.m[2][1]-b.m[2][1],a.m[2][2]-b.m[2][2],a.m[2][3]-b.m[2][3],
-                 a.m[3][0]-b.m[3][0],a.m[3][1]-b.m[3][1],a.m[3][2]-b.m[3][2],a.m[3][3]-b.m[3][3]);
+FXMat4f FXMat4f::operator-(const FXMat4f& w) const {
+  return FXMat4f(m[0][0]-w[0][0],m[0][1]-w[0][1],m[0][2]-w[0][2],m[0][3]-w[0][3],
+                 m[1][0]-w[1][0],m[1][1]-w[1][1],m[1][2]-w[1][2],m[1][3]-w[1][3],
+                 m[2][0]-w[2][0],m[2][1]-w[2][1],m[2][2]-w[2][2],m[2][3]-w[2][3],
+                 m[3][0]-w[3][0],m[3][1]-w[3][1],m[3][2]-w[3][2],m[3][3]-w[3][3]);
   }
 
 
-// Negate matrix
-FXMat4f operator-(const FXMat4f& a){
-  return FXMat4f(-a[0][0],-a[0][1],-a[0][2],-a[0][3],
-                 -a[1][0],-a[1][1],-a[1][2],-a[1][3],
-                 -a[2][0],-a[2][1],-a[2][2],-a[2][3],
-                 -a[3][0],-a[3][1],-a[3][2],-a[3][3]);
-  }
-
-
-
 // Composite matrices
-FXMat4f operator*(const FXMat4f& a,const FXMat4f& b){
-  FXMat4f r;
+FXMat4f FXMat4f::operator*(const FXMat4f& w) const {
   register FXfloat x,y,z,h;
-  x=a[0][0]; y=a[0][1]; z=a[0][2]; h=a[0][3];
-  r[0][0]=x*b[0][0]+y*b[1][0]+z*b[2][0]+h*b[3][0];
-  r[0][1]=x*b[0][1]+y*b[1][1]+z*b[2][1]+h*b[3][1];
-  r[0][2]=x*b[0][2]+y*b[1][2]+z*b[2][2]+h*b[3][2];
-  r[0][3]=x*b[0][3]+y*b[1][3]+z*b[2][3]+h*b[3][3];
-  x=a[1][0]; y=a[1][1]; z=a[1][2]; h=a[1][3];
-  r[1][0]=x*b[0][0]+y*b[1][0]+z*b[2][0]+h*b[3][0];
-  r[1][1]=x*b[0][1]+y*b[1][1]+z*b[2][1]+h*b[3][1];
-  r[1][2]=x*b[0][2]+y*b[1][2]+z*b[2][2]+h*b[3][2];
-  r[1][3]=x*b[0][3]+y*b[1][3]+z*b[2][3]+h*b[3][3];
-  x=a[2][0]; y=a[2][1]; z=a[2][2]; h=a[2][3];
-  r[2][0]=x*b[0][0]+y*b[1][0]+z*b[2][0]+h*b[3][0];
-  r[2][1]=x*b[0][1]+y*b[1][1]+z*b[2][1]+h*b[3][1];
-  r[2][2]=x*b[0][2]+y*b[1][2]+z*b[2][2]+h*b[3][2];
-  r[2][3]=x*b[0][3]+y*b[1][3]+z*b[2][3]+h*b[3][3];
-  x=a[3][0]; y=a[3][1]; z=a[3][2]; h=a[3][3];
-  r[3][0]=x*b[0][0]+y*b[1][0]+z*b[2][0]+h*b[3][0];
-  r[3][1]=x*b[0][1]+y*b[1][1]+z*b[2][1]+h*b[3][1];
-  r[3][2]=x*b[0][2]+y*b[1][2]+z*b[2][2]+h*b[3][2];
-  r[3][3]=x*b[0][3]+y*b[1][3]+z*b[2][3]+h*b[3][3];
+  FXMat4f r;
+  x=m[0][0]; y=m[0][1]; z=m[0][2]; h=m[0][3];
+  r[0][0]=x*w[0][0]+y*w[1][0]+z*w[2][0]+h*w[3][0];
+  r[0][1]=x*w[0][1]+y*w[1][1]+z*w[2][1]+h*w[3][1];
+  r[0][2]=x*w[0][2]+y*w[1][2]+z*w[2][2]+h*w[3][2];
+  r[0][3]=x*w[0][3]+y*w[1][3]+z*w[2][3]+h*w[3][3];
+  x=m[1][0]; y=m[1][1]; z=m[1][2]; h=m[1][3];
+  r[1][0]=x*w[0][0]+y*w[1][0]+z*w[2][0]+h*w[3][0];
+  r[1][1]=x*w[0][1]+y*w[1][1]+z*w[2][1]+h*w[3][1];
+  r[1][2]=x*w[0][2]+y*w[1][2]+z*w[2][2]+h*w[3][2];
+  r[1][3]=x*w[0][3]+y*w[1][3]+z*w[2][3]+h*w[3][3];
+  x=m[2][0]; y=m[2][1]; z=m[2][2]; h=m[2][3];
+  r[2][0]=x*w[0][0]+y*w[1][0]+z*w[2][0]+h*w[3][0];
+  r[2][1]=x*w[0][1]+y*w[1][1]+z*w[2][1]+h*w[3][1];
+  r[2][2]=x*w[0][2]+y*w[1][2]+z*w[2][2]+h*w[3][2];
+  r[2][3]=x*w[0][3]+y*w[1][3]+z*w[2][3]+h*w[3][3];
+  x=m[3][0]; y=m[3][1]; z=m[3][2]; h=m[3][3];
+  r[3][0]=x*w[0][0]+y*w[1][0]+z*w[2][0]+h*w[3][0];
+  r[3][1]=x*w[0][1]+y*w[1][1]+z*w[2][1]+h*w[3][1];
+  r[3][2]=x*w[0][2]+y*w[1][2]+z*w[2][2]+h*w[3][2];
+  r[3][3]=x*w[0][3]+y*w[1][3]+z*w[2][3]+h*w[3][3];
   return r;
   }
 
@@ -283,43 +325,18 @@ FXMat4f operator/(const FXMat4f& a,FXfloat x){
   }
 
 
-// Vector times matrix
-FXVec4f operator*(const FXVec4f& v,const FXMat4f& m){
+// Matrix times vector
+FXVec4f FXMat4f::operator*(const FXVec4f& v) const {
   register FXfloat x=v.x,y=v.y,z=v.z,w=v.w;
-  return FXVec4f(x*m[0][0]+y*m[1][0]+z*m[2][0]+w*m[3][0],
-                 x*m[0][1]+y*m[1][1]+z*m[2][1]+w*m[3][1],
-                 x*m[0][2]+y*m[1][2]+z*m[2][2]+w*m[3][2],
-                 x*m[0][3]+y*m[1][3]+z*m[2][3]+w*m[3][3]);
+  return FXVec4f(x*m[0][0]+y*m[0][1]+z*m[0][2]+w*m[0][3], x*m[1][0]+y*m[1][1]+z*m[1][2]+w*m[1][3], x*m[2][0]+y*m[2][1]+z*m[2][2]+w*m[2][3], x*m[3][0]+y*m[3][1]+z*m[3][2]+w*m[3][3]);
   }
 
 
 // Matrix times vector
-FXVec4f operator*(const FXMat4f& m,const FXVec4f& v){
-  register FXfloat x=v.x,y=v.y,z=v.z,w=v.w;
-  return FXVec4f(x*m[0][0]+y*m[0][1]+z*m[0][2]+w*m[0][3],
-                 x*m[1][0]+y*m[1][1]+z*m[1][2]+w*m[1][3],
-                 x*m[2][0]+y*m[2][1]+z*m[2][2]+w*m[2][3],
-                 x*m[3][0]+y*m[3][1]+z*m[3][2]+w*m[3][3]);
-  }
-
-
-// Vector times matrix
-FXVec3f operator*(const FXVec3f& v,const FXMat4f& m){
+FXVec3f FXMat4f::operator*(const FXVec3f& v) const {
   register FXfloat x=v.x,y=v.y,z=v.z;
   FXASSERT(m[0][3]==0.0f && m[1][3]==0.0f && m[2][3]==0.0f && m[3][3]==1.0f);
-  return FXVec3f(x*m[0][0]+y*m[1][0]+z*m[2][0]+m[3][0],
-                 x*m[0][1]+y*m[1][1]+z*m[2][1]+m[3][1],
-                 x*m[0][2]+y*m[1][2]+z*m[2][2]+m[3][2]);
-  }
-
-
-// Matrix times vector
-FXVec3f operator*(const FXMat4f& m,const FXVec3f& v){
-  register FXfloat x=v.x,y=v.y,z=v.z;
-  FXASSERT(m[0][3]==0.0f && m[1][3]==0.0f && m[2][3]==0.0f && m[3][3]==1.0f);
-  return FXVec3f(x*m[0][0]+y*m[0][1]+z*m[0][2]+m[0][3],
-                 x*m[1][0]+y*m[1][1]+z*m[1][2]+m[1][3],
-                 x*m[2][0]+y*m[2][1]+z*m[2][2]+m[2][3]);
+  return FXVec3f(x*m[0][0]+y*m[0][1]+z*m[0][2]+m[0][3], x*m[1][0]+y*m[1][1]+z*m[1][2]+m[1][3], x*m[2][0]+y*m[2][1]+z*m[2][2]+m[2][3]);
   }
 
 
@@ -447,7 +464,7 @@ FXMat4f& FXMat4f::rot(const FXQuatf& q){
   register FXfloat x,y,z;
 
   // Get rotation matrix
-  FXMat3f r=toMatrix(q);
+  FXMat3f r(q);
 
   // Pre-multiply
   x=m[0][0]; y=m[1][0]; z=m[2][0];
@@ -623,27 +640,27 @@ FXMat4f& FXMat4f::scale(const FXVec3f& v){
 
 
 // Calculate determinant
-FXfloat det(const FXMat4f& a){
-  return DET4(a[0][0],a[0][1],a[0][2],a[0][3],
-              a[1][0],a[1][1],a[1][2],a[1][3],
-              a[2][0],a[2][1],a[2][2],a[2][3],
-              a[3][0],a[3][1],a[3][2],a[3][3]);
+FXfloat FXMat4f::det() const {
+  return DET4(m[0][0],m[0][1],m[0][2],m[0][3],
+              m[1][0],m[1][1],m[1][2],m[1][3],
+              m[2][0],m[2][1],m[2][2],m[2][3],
+              m[3][0],m[3][1],m[3][2],m[3][3]);
   }
 
 
 // Transpose matrix
-FXMat4f transpose(const FXMat4f& a){
-  return FXMat4f(a[0][0],a[1][0],a[2][0],a[3][0],
-                 a[0][1],a[1][1],a[2][1],a[3][1],
-                 a[0][2],a[1][2],a[2][2],a[3][2],
-                 a[0][3],a[1][3],a[2][3],a[3][3]);
+FXMat4f FXMat4f::transpose() const {
+  return FXMat4f(m[0][0],m[1][0],m[2][0],m[3][0],
+                 m[0][1],m[1][1],m[2][1],m[3][1],
+                 m[0][2],m[1][2],m[2][2],m[3][2],
+                 m[0][3],m[1][3],m[2][3],m[3][3]);
   }
 
 
 // Invert matrix
-FXMat4f invert(const FXMat4f& s){
-  FXMat4f m(1.0f,0.0f,0.0f,0.0f,0.0f,1.0f,0.0f,0.0f,0.0f,0.0f,1.0f,0.0f,0.0f,0.0f,0.0f,1.0f);
-  FXMat4f x(s);
+FXMat4f FXMat4f::invert() const {
+  FXMat4f r(1.0f,0.0f,0.0f,0.0f,0.0f,1.0f,0.0f,0.0f,0.0f,0.0f,1.0f,0.0f,0.0f,0.0f,0.0f,1.0f);
+  FXMat4f x(*this);
   register FXfloat pvv,t;
   register int i,j,pvi;
   for(i=0; i<4; i++){
@@ -657,20 +674,20 @@ FXMat4f invert(const FXMat4f& s){
       }
     FXASSERT(pvv != 0.0f);  // Should not be singular
     if(pvi!=i){             // Swap rows i and pvi
-      FXSWAP(m[i][0],m[pvi][0],t); FXSWAP(m[i][1],m[pvi][1],t); FXSWAP(m[i][2],m[pvi][2],t); FXSWAP(m[i][3],m[pvi][3],t);
+      FXSWAP(r[i][0],r[pvi][0],t); FXSWAP(r[i][1],r[pvi][1],t); FXSWAP(r[i][2],r[pvi][2],t); FXSWAP(r[i][3],r[pvi][3],t);
       FXSWAP(x[i][0],x[pvi][0],t); FXSWAP(x[i][1],x[pvi][1],t); FXSWAP(x[i][2],x[pvi][2],t); FXSWAP(x[i][3],x[pvi][3],t);
       }
     x[i][0]/=pvv; x[i][1]/=pvv; x[i][2]/=pvv; x[i][3]/=pvv;
-    m[i][0]/=pvv; m[i][1]/=pvv; m[i][2]/=pvv; m[i][3]/=pvv;
+    r[i][0]/=pvv; r[i][1]/=pvv; r[i][2]/=pvv; r[i][3]/=pvv;
     for(j=0; j<4; j++){     // Eliminate column i
       if(j!=i){
         t=x[j][i];
         x[j][0]-=x[i][0]*t; x[j][1]-=x[i][1]*t; x[j][2]-=x[i][2]*t; x[j][3]-=x[i][3]*t;
-        m[j][0]-=m[i][0]*t; m[j][1]-=m[i][1]*t; m[j][2]-=m[i][2]*t; m[j][3]-=m[i][3]*t;
+        r[j][0]-=r[i][0]*t; r[j][1]-=r[i][1]*t; r[j][2]-=r[i][2]*t; r[j][3]-=r[i][3]*t;
         }
       }
     }
-  return m;
+  return r;
   }
 
 
