@@ -3,7 +3,7 @@
 *             R e a l - V a l u e d   S p i n n e r  W i d g e t                *
 *                                                                               *
 *********************************************************************************
-* Copyright (C) 2003,2005 by Bill Baxter.   All Rights Reserved.                *
+* Copyright (C) 2003,2006 by Bill Baxter.   All Rights Reserved.                *
 *********************************************************************************
 * This library is free software; you can redistribute it and/or                 *
 * modify it under the terms of the GNU Lesser General Public                    *
@@ -19,7 +19,7 @@
 * License along with this library; if not, write to the Free Software           *
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA.    *
 *********************************************************************************
-* $Id: FXRealSpinner.cpp,v 1.27 2005/01/16 16:06:07 fox Exp $                   *
+* $Id: FXRealSpinner.cpp,v 1.38.2.1 2006/03/31 21:25:59 fox Exp $                   *
 ********************************************************************************/
 #include "xincs.h"
 #include "fxver.h"
@@ -48,8 +48,6 @@
     with the dial was impossible.
   - Wheel mouse offers incrementation/decrementation in nice
     multiples of increment, makes it very quick to get a value.
-  - Needed rather complicated mechanism so as to ensure a "wheely"
-    up and down gets you back to EXACTLY the same number!
 */
 
 #define BUTTONWIDTH 14
@@ -68,7 +66,6 @@ FXDEFMAP(FXRealSpinner) FXRealSpinnerMap[]={
   FXMAPFUNC(SEL_KEYPRESS,0,FXRealSpinner::onKeyPress),
   FXMAPFUNC(SEL_KEYRELEASE,0,FXRealSpinner::onKeyRelease),
   FXMAPFUNC(SEL_FOCUS_SELF,0,FXRealSpinner::onFocusSelf),
-//  FXMAPFUNC(SEL_UPDATE,FXRealSpinner::ID_ENTRY,FXRealSpinner::onUpdEntry),
   FXMAPFUNC(SEL_COMMAND,FXRealSpinner::ID_ENTRY,FXRealSpinner::onCmdEntry),
   FXMAPFUNC(SEL_CHANGED,FXRealSpinner::ID_ENTRY,FXRealSpinner::onChgEntry),
   FXMAPFUNC(SEL_MOUSEWHEEL,FXRealSpinner::ID_ENTRY,FXRealSpinner::onWheelEntry),
@@ -100,10 +97,9 @@ FXRealSpinner::FXRealSpinner(){
   downButton=(FXArrowButton*)-1L;
   range[0]=-DBL_MAX;
   range[1]= DBL_MAX;
-  base=0.0;
   incr=1.0;
+  gran=0.0;
   pos=0.0;
-  ticks=0;
   }
 
 
@@ -119,10 +115,9 @@ FXRealSpinner::FXRealSpinner(FXComposite *p,FXint cols,FXObject *tgt,FXSelector
   range[0]=(options&REALSPIN_NOMIN) ? -DBL_MAX : 0.0;
   range[1]=(options&REALSPIN_NOMAX) ?  DBL_MAX : 100.0;
   textField->setText("0");
-  base=0.0;
   incr=1.0;
+  gran=0.0;
   pos=0.0;
-  ticks=0;
   }
 
 
@@ -201,8 +196,7 @@ long FXRealSpinner::onUpdIncrement(FXObject* sender,FXSelector,void*){
 // Respond to increment message
 long FXRealSpinner::onCmdIncrement(FXObject*,FXSelector,void*){
   if(isEnabled() && isEditable()){
-    increment();
-    if(target) target->tryHandle(this,FXSEL(SEL_COMMAND,message),(void*)&pos);
+    increment(TRUE);
     return 1;
     }
   return 0;
@@ -222,8 +216,7 @@ long FXRealSpinner::onUpdDecrement(FXObject* sender,FXSelector,void*){
 // Respond to decrement message
 long FXRealSpinner::onCmdDecrement(FXObject*,FXSelector,void*){
   if(isEnabled() && isEditable()){
-    decrement();
-    if(target) target->tryHandle(this,FXSEL(SEL_COMMAND,message),(void*)&pos);
+    decrement(TRUE);
     return 1;
     }
   return 0;
@@ -232,12 +225,16 @@ long FXRealSpinner::onCmdDecrement(FXObject*,FXSelector,void*){
 
 // Rolling mouse wheel in text field behaves as if inside dial
 long FXRealSpinner::onWheelEntry(FXObject*,FXSelector,void* ptr){
+  FXEvent* event=(FXEvent*)ptr;
   if(isEnabled() && isEditable()){
-    if(((FXEvent*)ptr)->code>0)
-      increment();
-    else
-      decrement();
-    if(target) target->tryHandle(this,FXSEL(SEL_COMMAND,message),(void*)&pos);
+    if(((FXEvent*)ptr)->code>0){
+      if(event->state&CONTROLMASK) incrementByAmount(incr*10.0,TRUE);
+      else increment(TRUE);
+      }
+    else{
+      if(event->state&CONTROLMASK) decrementByAmount(incr*10.0,TRUE);
+      else decrement(TRUE);
+      }
     return 1;
     }
   return 0;
@@ -250,8 +247,7 @@ long FXRealSpinner::onChgEntry(FXObject*,FXSelector,void*){
   if(value<range[0]) value=range[0];
   if(value>range[1]) value=range[1];
   if(value!=pos){
-    pos=base=value;
-    ticks=0;
+    pos=value;
     if(target) target->tryHandle(this,FXSEL(SEL_CHANGED,message),(void*)&pos);
     }
   return 1;
@@ -275,8 +271,7 @@ long FXRealSpinner::onKeyPress(FXObject* sender,FXSelector sel,void* ptr){
       case KEY_Up:
       case KEY_KP_Up:
         if(isEditable()){
-          increment();
-          if(target) target->tryHandle(this,FXSEL(SEL_COMMAND,message),(void*)&pos);
+          increment(TRUE);
           }
         else{
           getApp()->beep();
@@ -285,8 +280,7 @@ long FXRealSpinner::onKeyPress(FXObject* sender,FXSelector sel,void* ptr){
       case KEY_Down:
       case KEY_KP_Down:
         if(isEditable()){
-          decrement();
-          if(target) target->tryHandle(this,FXSEL(SEL_COMMAND,message),(void*)&pos);
+          decrement(TRUE);
           }
         else{
           getApp()->beep();
@@ -391,41 +385,58 @@ long FXRealSpinner::onCmdGetRealRange(FXObject*,FXSelector,void* ptr){
 
 
 // Increment spinner
-void FXRealSpinner::increment(){
-  if(range[0]<range[1]){
-    if(options&REALSPIN_CYCLIC){
-      FXdouble value=++ticks*incr+base;
-      pos=value-floor((value-range[0])/(range[1]-range[0]))*(range[1]-range[0]);
-      }
-    else if(options&REALSPIN_LOG){
-      pos=base*pow(10.0,++ticks*incr);
-      if(pos>range[1]){pos=base=range[1];ticks=0;}
+void FXRealSpinner::increment(FXbool notify){
+  incrementByAmount(incr,notify);
+  }
+
+
+#if defined(WIN32) || defined(__sgi) || defined(__sun) || defined(__alpha)
+double round(double x){
+  return (x >= 0) ? floor(x+0.5) : ceil(x-0.5);
+  }
+#endif
+
+
+// Increment spinner by certain amount
+void FXRealSpinner::incrementByAmount(FXdouble amount,FXbool notify){
+  if(range[0]<range[1] && 0.0<amount){
+    FXdouble value;
+    if(options&REALSPIN_LOG){
+      value=pos*amount;
       }
     else{
-      pos=++ticks*incr+base;
-      if(pos>range[1]){pos=base=range[1];ticks=0;}
+      value=pos+amount;
+      if(0<gran) value=gran*round(value/gran);
+      if(options&REALSPIN_CYCLIC){
+        value=value-floor((value-range[0])/(range[1]-range[0]))*(range[1]-range[0]);
+        }
       }
-    textField->setText(FXStringVal(pos));
+    setValue(value,notify);
     }
   }
 
 
 // Decrement spinner
-void FXRealSpinner::decrement(){
-  if(range[0]<range[1]){
-    if(options&REALSPIN_CYCLIC){
-      FXdouble value=--ticks*incr+base;
-      pos=value-floor((value-range[0])/(range[1]-range[0]))*(range[1]-range[0]);
-      }
-    else if(options&REALSPIN_LOG){
-      pos=base*pow(10.0,--ticks*incr);
-      if(pos<range[0]){pos=base=range[0];ticks=0;}
+void FXRealSpinner::decrement(FXbool notify){
+  decrementByAmount(incr,notify);
+  }
+
+
+// Decrement spinner by certain amount
+void FXRealSpinner::decrementByAmount(FXdouble amount,FXbool notify){
+  if(range[0]<range[1] && 0.0<amount){
+    FXdouble value;
+    if(options&REALSPIN_LOG){
+      value=pos/amount;
       }
     else{
-      pos=--ticks*incr+base;
-      if(pos<range[0]){pos=base=range[0];ticks=0;}
+      value=pos-amount;
+      if(0<gran) value=gran*round(value/gran);
+      if(options&REALSPIN_CYCLIC){
+        value=value-floor((value-range[0])/(range[1]-range[0]))*(range[1]-range[0]);
+        }
       }
-    textField->setText(FXStringVal(pos));
+    setValue(value,notify);
     }
   }
 
@@ -443,23 +454,24 @@ void FXRealSpinner::setCyclic(FXbool cyclic){
 
 
 // Set spinner range; this also revalidates the position,
-void FXRealSpinner::setRange(FXdouble lo,FXdouble hi){
+void FXRealSpinner::setRange(FXdouble lo,FXdouble hi,FXbool notify){
   if(lo>hi){ fxerror("%s::setRange: trying to set negative range.\n",getClassName()); }
   if(range[0]!=lo || range[1]!=hi){
     range[0]=lo;
     range[1]=hi;
-    setValue(pos);
+    setValue(pos,notify);
     }
   }
 
 
 // Set new value
-void FXRealSpinner::setValue(FXdouble value){
+void FXRealSpinner::setValue(FXdouble value,FXbool notify){
   if(value<range[0]) value=range[0];
   if(value>range[1]) value=range[1];
   if(pos!=value){
     textField->setText(FXStringVal(value));
-    pos=base=value; ticks=0;
+    pos=value;
+    if(notify && target){target->tryHandle(this,FXSEL(SEL_COMMAND,message),(void*)&pos);}
     }
   }
 
@@ -467,7 +479,15 @@ void FXRealSpinner::setValue(FXdouble value){
 // Change value increment
 void FXRealSpinner::setIncrement(FXdouble inc){
   if(inc<=0.0){ fxerror("%s::setIncrement: negative or zero increment specified.\n",getClassName()); }
-  incr=inc; base=pos; ticks=0;
+  incr=inc;
+  }
+
+
+
+// Change spinner granularity
+void FXRealSpinner::setGranularity(FXdouble gr){
+  if(gr<0.0){ fxerror("%s::setGranularity: negative granularity specified.\n",getClassName()); }
+  gran=gr;
   }
 
 
@@ -488,7 +508,7 @@ void FXRealSpinner::setTextVisible(FXbool shown){
 
 
 // Set the font used in the text field|
-void FXRealSpinner::setFont(FXFont *fnt) {
+void FXRealSpinner::setFont(FXFont *fnt){
   textField->setFont(fnt);
   }
 
@@ -638,6 +658,7 @@ void FXRealSpinner::save(FXStream& store) const {
   store << downButton;
   store << range[0] << range[1];
   store << incr;
+  store << gran;
   store << pos;
   }
 
@@ -650,6 +671,7 @@ void FXRealSpinner::load(FXStream& store){
   store >> downButton;
   store >> range[0] >> range[1];
   store >> incr;
+  store >> gran;
   store >> pos;
   }
 
