@@ -3,7 +3,7 @@
 *                     R e c e n t   F i l e s   L i s t                         *
 *                                                                               *
 *********************************************************************************
-* Copyright (C) 1998,2005 by Jeroen van der Zijp.   All Rights Reserved.        *
+* Copyright (C) 1998,2006 by Jeroen van der Zijp.   All Rights Reserved.        *
 *********************************************************************************
 * This library is free software; you can redistribute it and/or                 *
 * modify it under the terms of the GNU Lesser General Public                    *
@@ -19,7 +19,7 @@
 * License along with this library; if not, write to the Free Software           *
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA.    *
 *********************************************************************************
-* $Id: FXRecentFiles.cpp,v 1.31 2005/01/16 16:06:07 fox Exp $                   *
+* $Id: FXRecentFiles.cpp,v 1.36 2006/01/22 17:58:39 fox Exp $                   *
 ********************************************************************************/
 #include "xincs.h"
 #include "fxver.h"
@@ -42,8 +42,7 @@
   Notes:
   - Use the auto-hide or auto-gray feature to hide menus which are connected
     to the FXRecentFiles class.
-  - Probably should get rid of application instance in favor of explicit
-    backlink to FXApp, or backlink to registry.
+  - Default constructor should probably be deprecated in applications.
 */
 
 using namespace FX;
@@ -66,22 +65,26 @@ FXDEFMAP(FXRecentFiles) FXRecentFilesMap[] = {
 FXIMPLEMENT(FXRecentFiles,FXObject,FXRecentFilesMap,ARRAYNUMBER(FXRecentFilesMap))
 
 
+// Serialization
+FXRecentFiles::FXRecentFiles():app(FXApp::instance()),target(NULL),message(0),group("Recent Files"),maxfiles(10){
+  }
+
+
 // Make new Recent Files group with default group
-FXRecentFiles::FXRecentFiles():group("Recent Files"),target(NULL),message(0),maxfiles(10){
+FXRecentFiles::FXRecentFiles(FXApp* a):app(a),target(NULL),message(0),group("Recent Files"),maxfiles(10){
   }
 
 
 // Make new Recent Files group
-FXRecentFiles::FXRecentFiles(const FXString& gp,FXObject *tgt,FXSelector sel):group(gp),target(tgt),message(sel),maxfiles(10){
+FXRecentFiles::FXRecentFiles(FXApp* a,const FXString& gp,FXObject *tgt,FXSelector sel):app(a),target(tgt),message(sel),group(gp),maxfiles(10){
   }
 
 
-
 // Obtain the filename at index
 FXString FXRecentFiles::getFile(FXint index) const {
   FXchar key[20];
   sprintf(key,"FILE%d",index);
-  return FXApp::instance()->reg().readStringEntry(group.text(),key,FXString::null);
+  return app->reg().readStringEntry(group.text(),key,FXString::null);
   }
 
 
@@ -89,7 +92,7 @@ FXString FXRecentFiles::getFile(FXint index) const {
 void FXRecentFiles::setFile(FXint index,const FXString& filename){
   FXchar key[20];
   sprintf(key,"FILE%d",index);
-  FXApp::instance()->reg().writeStringEntry(group.text(),key,filename.text());
+  app->reg().writeStringEntry(group.text(),key,filename.text());
   }
 
 
@@ -103,11 +106,11 @@ void FXRecentFiles::appendFile(const FXString& filename){
   do{
     do{
       sprintf(key,"FILE%d",j++);
-      oldname=FXApp::instance()->reg().readStringEntry(group.text(),key,NULL);
+      oldname=app->reg().readStringEntry(group.text(),key,NULL);
       }
     while(oldname==filename);
     sprintf(key,"FILE%d",i++);
-    FXApp::instance()->reg().writeStringEntry(group.text(),key,newname.text());
+    app->reg().writeStringEntry(group.text(),key,newname.text());
     newname=oldname;
     }
   while(!oldname.empty() && i<=maxfiles);
@@ -121,12 +124,12 @@ void FXRecentFiles::removeFile(const FXString& filename){
   FXint i=1,j=1;
   do{
     sprintf(key,"FILE%d",i++);
-    name=FXApp::instance()->reg().readStringEntry(group.text(),key,NULL);
-    FXApp::instance()->reg().deleteEntry(group.text(),key);
+    name=app->reg().readStringEntry(group.text(),key,NULL);
+    app->reg().deleteEntry(group.text(),key);
     if(name.empty()) break;
     if(name!=filename){
       sprintf(key,"FILE%d",j++);
-      FXApp::instance()->reg().writeStringEntry(group.text(),key,name.text());
+      app->reg().writeStringEntry(group.text(),key,name.text());
       }
     }
   while(i<=maxfiles);
@@ -135,7 +138,7 @@ void FXRecentFiles::removeFile(const FXString& filename){
 
 // Remove all files from the list
 void FXRecentFiles::clear(){
-  FXApp::instance()->reg().deleteSection(group.text());
+  app->reg().deleteSection(group.text());
   }
 
 
@@ -152,7 +155,7 @@ long FXRecentFiles::onCmdFile(FXObject*,FXSelector sel,void*){
   FXchar key[20];
   if(target){
     sprintf(key,"FILE%d",(FXSELID(sel)-ID_FILE_1+1));
-    filename=FXApp::instance()->reg().readStringEntry(group.text(),key,NULL);
+    filename=app->reg().readStringEntry(group.text(),key,NULL);
     if(filename){
       target->handle(this,FXSEL(SEL_COMMAND,message),(void*)filename);
       }
@@ -168,7 +171,7 @@ long FXRecentFiles::onUpdFile(FXObject *sender,FXSelector sel,void*){
   FXString string;
   FXchar key[20];
   sprintf(key,"FILE%d",which);
-  filename=FXApp::instance()->reg().readStringEntry(group.text(),key,NULL);
+  filename=app->reg().readStringEntry(group.text(),key,NULL);
   if(filename){
     FXString string;
     if(which<10)
@@ -187,7 +190,7 @@ long FXRecentFiles::onUpdFile(FXObject *sender,FXSelector sel,void*){
 
 // Show or hide depending on whether there are any files
 long FXRecentFiles::onUpdAnyFiles(FXObject *sender,FXSelector,void*){
-  if(FXApp::instance()->reg().readStringEntry(group.text(),"FILE1",NULL))
+  if(app->reg().readStringEntry(group.text(),"FILE1",NULL))
     sender->handle(this,FXSEL(SEL_COMMAND,FXWindow::ID_SHOW),NULL);
   else
     sender->handle(this,FXSEL(SEL_COMMAND,FXWindow::ID_HIDE),NULL);
@@ -198,9 +201,10 @@ long FXRecentFiles::onUpdAnyFiles(FXObject *sender,FXSelector,void*){
 // Save data
 void FXRecentFiles::save(FXStream& store) const {
   FXObject::save(store);
-  store << group;
+  store << app;
   store << target;
   store << message;
+  store << group;
   store << maxfiles;
   }
 
@@ -208,9 +212,10 @@ void FXRecentFiles::save(FXStream& store) const {
 // Load data
 void FXRecentFiles::load(FXStream& store){
   FXObject::load(store);
-  store >> group;
+  store >> app;
   store >> target;
   store >> message;
+  store >> group;
   store >> maxfiles;
   }
 
