@@ -19,8 +19,10 @@
 * License along with this library; if not, write to the Free Software           *
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA.    *
 *********************************************************************************
-* $Id: fxpriv.h,v 1.36.2.1 2006/03/28 13:02:54 fox Exp $                            *
+* $Id: fxpriv.h,v 1.36.2.3 2008/09/22 20:49:44 fox Exp $                            *
 ********************************************************************************/
+#ifndef FXPRIV_H
+#define FXPRIV_H
 
 namespace FX {
 
@@ -51,6 +53,33 @@ namespace FX {
 #define WM_DND_FINISH_PRIVATE   (WM_APP+20)
 #endif
 
+// Definitions for multi-head displays on Windows
+#ifdef WIN32
+#ifndef MONITOR_DEFAULTTONULL
+#define MONITOR_DEFAULTTONULL       0x00000000
+#endif
+#ifndef MONITOR_DEFAULTTOPRIMARY
+#define MONITOR_DEFAULTTOPRIMARY    0x00000001
+#endif
+#ifndef MONITOR_DEFAULTTONEAREST
+#define MONITOR_DEFAULTTONEAREST    0x00000002
+#endif
+#ifndef MONITORINFOF_PRIMARY
+#define MONITORINFOF_PRIMARY        0x00000001
+#endif
+
+struct MYMONITORINFO {
+  DWORD   cbSize;
+  RECT    rcMonitor;
+  RECT    rcWork;
+  DWORD   dwFlags;
+  };
+
+
+typedef BOOL (WINAPI *PFNGETMONITORINFO)(HANDLE monitor,MYMONITORINFO* minfo);
+typedef HANDLE (WINAPI *PFNMONITORFROMRECT)(RECT* rect,DWORD flags);
+
+#endif
 
 
 // Named color
@@ -81,27 +110,30 @@ extern FXbool fxwuquantize(FXuchar* dst,const FXColor* src,FXColor* colormap,FXi
 
 // X11 helpers
 #ifndef WIN32
-extern FXAPI Atom fxsendrequest(Display *display,Window window,Atom selection,Atom prop,Atom type,FXuint time);
-extern FXAPI Atom fxsendreply(Display *display,Window window,Atom selection,Atom prop,Atom target,FXuint time);
-extern FXAPI Atom fxsendtypes(Display *display,Window window,Atom prop,FXDragType* types,FXuint numtypes);
-extern FXAPI Atom fxrecvtypes(Display *display,Window window,Atom prop,FXDragType*& types,FXuint& numtypes,FXbool del);
-extern FXAPI Atom fxsenddata(Display *display,Window window,Atom prop,Atom type,FXuchar* data,FXuint size);
-extern FXAPI Atom fxrecvdata(Display *display,Window window,Atom prop,Atom incr,Atom& type,FXuchar*& data,FXuint& size);
+extern Atom fxsendrequest(Display *display,Window window,Atom selection,Atom prop,Atom type,FXuint time);
+extern Atom fxsendreply(Display *display,Window window,Atom selection,Atom prop,Atom target,FXuint time);
+extern Atom fxsendtypes(Display *display,Window window,Atom prop,FXDragType* types,FXuint numtypes);
+extern Atom fxrecvtypes(Display *display,Window window,Atom prop,FXDragType*& types,FXuint& numtypes,FXbool del);
+extern Atom fxsenddata(Display *display,Window window,Atom prop,Atom type,FXuchar* data,FXuint size);
+extern Atom fxrecvdata(Display *display,Window window,Atom prop,Atom incr,Atom& type,FXuchar*& data,FXuint& size);
 #endif
 
 // Windows helpers
 #ifdef WIN32
-extern FXAPI HANDLE fxsendrequest(HWND window,HWND requestor,WPARAM type);
-extern FXAPI HANDLE fxsenddata(HWND window,FXuchar* data,FXuint size);
-extern FXAPI HANDLE fxrecvdata(HANDLE hMap,FXuchar*& data,FXuint& size);
-extern FXAPI FXuint fxmodifierkeys();
+extern HANDLE fxsendrequest(HWND window,HWND requestor,WPARAM type);
+extern HANDLE fxsenddata(HWND window,FXuchar* data,FXuint size);
+extern HANDLE fxrecvdata(HANDLE hMap,FXuchar*& data,FXuint& size);
+extern FXuint fxmodifierkeys();
 extern UINT wkbGetCodePage();
 extern FXuint wkbMapKeyCode(UINT iMsg, WPARAM uVirtKey, LPARAM lParam);
-extern FXAPI FXbool wkbTranslateMessage(HWND hWnd, UINT iMsg, WPARAM wParam,LPARAM lParam);
+extern FXbool wkbTranslateMessage(HWND hWnd, UINT iMsg, WPARAM wParam,LPARAM lParam);
 extern int (WINAPI *ToUnicodeEx)(UINT, UINT, const BYTE*, LPWSTR, int, UINT, HKL);
+extern PFNGETMONITORINFO fxGetMonitorInfo;
+extern PFNMONITORFROMRECT fxMonitorFromRect;
 #endif
 
 }
 
+#endif
 
 
