@@ -236,7 +236,7 @@ long TabBookWindow::onCmdHideShow(FXObject*,FXSelector,void*){
 
 // Active panel switched
 long TabBookWindow::onCmdPanel(FXObject*,FXSelector,void* ptr){
-  FXTRACE((1,"Panel = %d\n",(FXint)(long)ptr));
+  FXTRACE((1,"Panel = %d\n",(FXint)(FXival)ptr));
   return 1;
   }
 
